# This file was auto-generated by Fern from our API Definition.

import typing

from .non_stream_analyze_response import NonStreamAnalyzeResponse
from .stream_analyze_response import StreamAnalyzeResponse

GenerateResponse = typing.Union[StreamAnalyzeResponse, NonStreamAnalyzeResponse]
