# This file was auto-generated by Fern from our API Definition.

import typing

from .stream_end_response import StreamEndResponse
from .stream_start_response import StreamStartResponse
from .stream_text_response import StreamTextResponse

StreamAnalyzeResponse = typing.Union[StreamStartResponse, StreamTextResponse, StreamEndResponse]
