# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .transfers_create_response_failed_files_item import TransfersCreateResponseFailedFilesItem
from .transfers_create_response_videos_item import TransfersCreateResponseVideosItem


class TransfersCreateResponse(UniversalBaseModel):
    failed_files: typing.Optional[typing.List[TransfersCreateResponseFailedFilesItem]] = pydantic.Field(default=None)
    """
    A list of the video files that failed to import. Typically, these files did not meet the upload requirements. To resolve this, review the requirements listed in the [Prerequisites](/v1.3/docs/guides/search#prerequisites) section of the **Search** page.
    """

    videos: typing.Optional[typing.List[TransfersCreateResponseVideosItem]] = pydantic.Field(default=None)
    """
    A list of the videos that will be uploaded and indexed.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
