# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .summarize_chapter_result_chapters_item import SummarizeChapterResultChaptersItem
from .token_usage import TokenUsage


class SummarizeChapterResult(UniversalBaseModel):
    """
    An object that represents the response from a summarize chapter operation.
    """

    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Unique identifier of the response.
    """

    chapters: typing.Optional[typing.List[SummarizeChapterResultChaptersItem]] = pydantic.Field(default=None)
    """
    An array that contains details about the detected chapters and their content.
    """

    usage: typing.Optional[TokenUsage] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
